********************************************************************************

* Get GGS excerpt from harmonized history file

* reshape to union file : ggs_allunions.dta
* make person-year file : ppfile_allunions.dta

* reshape to kid file : ggs_allkids.dta
* make person-year file : ppfile_allkids.dta

********************************************************************************

*--------------------------------- specify your path here! ---------------------------*

global dir 	"C:\Users\Thomas Leopold\Dropbox\Adult_Child"

*-------------------------------------------------------------------------------------*

global data			"$data"		// HH, GGS, and UK files
global dofiles 		"$dir/1_dofiles"	// dofiles
global posted		"$posted"		// prepared data ready for analysis
global tables		"$dir/3_tables" 	// tables
global graphs 		"$dir/4_graphs" 	// graphs
global temp 		"$dir/5_temp" 		// temporary files



********************************************************************************
* make edu vars from original ggp data
********************************************************************************
use "$data/ContinuousSESvariables_GGP.dta", clear
sort acountry arid
save "$posted/isleddata", replace

use "$data/GGS_Wave1_Belgium_V.4.3.dta", clear
append using "$data/GGS_Wave1_France_V.4.3.dta", nolabel
append using "$data/GGS_Wave1_Norway_V.4.1.dta", nolabel
append using "$data/GGS_Wave1_Sweden_V.4.3.dta", nolabel
append using "$data/GGS_Wave1_Hungary_V.4.3.dta", nolabel
append using "$data/GGS_Wave1_Estonia_V.4.3.dta", nolabel
append using "$data/GGS_Wave1_CzechRepublic_V.4.3.dta", nolabel
keep acountry arid a148 a150AgeR 
sort acountry arid
merge 1:1 acountry arid using "$posted/isleddata.dta", keep(match master)
rename a148 isced_country 
rename a150AgeR age_edu

* adjust age leaving school
recode age_edu (.a=.)(.b=.)(.c=.)

* age primary often missing, set this to 14 before the recode (based on cases where this is known)
replace age_edu=14 if age_edu==. & (isced_country==1|isced_country==0)

* truncating age left school
recode age_edu (0/6=6)(25/max=25)

* country recode to edu years
egen eduyrs=mean(age_edu), by(acountry isced_country)
replace eduyrs=. if acountry==16|acountry==20
replace eduyrs=round(eduyrs,.1)
replace eduyrs=eduyrs-6
label variable eduyrs "Years country specific"

table isced_country if acountry==16

* country recode to isled
egen eduisled=mean(educ_isled), by(acountry isced_country)
replace eduisled=round(eduisled,.1)
label variable eduisled "ISLED"

* overall recode to eduyrs
recode isced_country (.a .b .c=.)(1407 1408 1409=.)(0 1 2=2)(5 6=5)(1501=1502)
recode isced_country (1502=2)(1503 1504 1505=3)(1506 1507=5) if acountry==15
egen edu_rest=mean(age_edu), by(isced_country)
gen edu=edu_rest-6
replace edu=round(edu, .1)
label variable edu "Years of education"

* recode to dichotomy
recode isced_country (2 3=0)(4 5=1)(else=.), gen(dedu)
label variable dedu "Higher educated"

bys acountry: sum edu eduyrs eduisled dedu

* show values
label variable edu "Education"
tab edu acountry
ssc install asdoc, replace
asdoc tab edu acountry, col nofreq
keep acountry arid edu dedu eduyrs eduisled
sort acountry arid
save "$posted/ggs_eduvars.dta", replace






********************************************************************************
* make excerpt-revision2 ggs data
********************************************************************************

use "$data/HARMONIZED-HISTORIES_ALL_GGSaccess", clear
* select countries
keep if inlist(country,561,2501,5781,7521,3481,2031,2331,8261)

* adjusting for oversample of wales, scotland and northern ireland based on hhweight in the file
recode region (826101/826116=1)(826117=2)(826118=3)(826119=4)(else=.), gen(uksubs)
label define uksubs 1 "england" 2 "wales (4.8%)" 3 "scotland (8.3%)" 4 "north ireland (2.8%)"
label values uksubs uksubs
sample 396 if uksubs==2 & country==8261, count
sample 685 if uksubs==3 & country==8261, count
sample 231 if uksubs==4 & country==8261, count

* country codes
recode country (561=23)(2501=15)(5781=20)(7521=29)(3481=16)(2031=28)(2331=22)(8261=.), gen(acountry) // for matching with original ggs data
label define acountry 23 "Belgium" 15 "France" 20 "Norway" 29 "Sweden" 16 "Hungary" 28 "Czech" 22 "Estonia"
label values acountry acountry
recode country (561=1)(2501=4)(5781=6)(7521=7)(3481=5)(2031=2)(2331=3)(8261=8), gen(ccc) // for own analyses
label define ccc 1 "Belgium" 2 "Czech" 3 "Estonia" 4 "France" 5 "Hungary" 6 "Norway" 7 "Sweden" 8 "UK"
label values ccc ccc

* education vars
sort acountry arid
merge acountry arid using "$posted/ggs_eduvars.dta"

* add education for UK
* overall years based on rest of the countries
recode isced_7 (1 2=9.1)(3=12.7)(5 6=17.1)(else=.) if country==8261, gen(edu_bhps)
drop if edu_cou==826113 | edu_cou==826197
* alternative for uk based on ghs 2005 and original edu codes in bhps
recode edu_cou (826101=15.6)(826102=14.8)(826103 826104 826105=12.5)(826106=12.3)(826107 826108 826109 826110=10.8)(826111 826112=9.3)(else=.), gen(edu_uk)
replace edu=edu_bhps if country==8261
replace eduyrs=edu_uk if country==8261
replace dedu=0 if country==8261 & (isced_7==1 | isced_7==2 | isced_7==3)
replace dedu=1 if country==8261 & (isced_7==5 | isced_7==6)
corr edu eduyrs eduisled

/*
These are the GHS year codes
No qualification			9.3	
O-levels					10.8	
A-levels					12.3	
Other higher qualification	12.5	
First degree 				14.8	
Higher degree				15.6	
*/

* drop missings
drop if ccc==.
drop if edu==.

* sex
recode sex (2=1)(else=0), gen(wom)
label variable wom "Woman"

* hungary has odd id nr, make new id, replace
bys ccc: gen aridnew=_n
gen id_person=10*aridnew+ccc

save "$posted/ggs_excerpt.dta", replace


********************************************************************************
* setup person-union file 
********************************************************************************

clear all
use "$posted/ggs_excerpt.dta"

list ccc arid union_1 union_y1 marr_1 marr_y1 div_1 div_y1 in 1/100

* reshape for each union
reshape long union_ union_y iunion_m marr_ marr_y imarr_m div_ div_y idiv_m sep_ sep_y isep_m numchp_, i(arid country) j(x)
keep if union_==1 
recode union_y marr_y (.a=.)(.b=.)
drop if union_y==. & marr_y==. // if no starting year info, delete
label variable x "Union number"
label define x 1 "1" 2 "2"
label values x x
recode sep_ (.a .b .c=.)
drop if sep_==. // no status of union
recode sep_ (2001 2901=1)(.=0) // 0 = widowed 1 = div or sep
gen curuni=0
replace curuni=1 if x==1 & sep_==0 
replace curuni=2 if x==2 & sep_==0 
replace curuni=3 if x==3 & sep_==0 
replace curuni=4 if x==4 & sep_==0 
replace curuni=5 if x==5 & sep_==0 
replace curuni=6 if x==6 & sep_==0 
replace curuni=7 if x==7 & sep_==0 
replace curuni=8 if x==8 & sep_==0 
replace curuni=9 if x==9 & sep_==0

* marriage years
gen yuni=union_y
gen ymar=marr_y
replace yuni=min(yuni,ymar) // if union after marriage start is marriage
gen ydis1=sep_y
gen ydis2=div_y
gen ydis=min(ydis1,ydis2)
gen tdis=sep_
label define tdis 0 "intact" 1 "separated" 2 "widowed"
label values tdis tdis

* Age at union
gen auni = yuni - born_y
label variable auni "Age union entry"

* Year of interview
gen yint = year_s

* Birth cohort
gen cbir=born_y

* Children
forvalues x = 1/16{
gen yc`x' = kid_y`x'
gen ac`x' = kid_y`x' - born_y
}
* delete 8 kids born before resp was 12
drop if ac1 < 12

* Age at parenthood
gen apar = min(kid_y1,kid_y2,kid_y3,kid_y4,kid_y5,kid_y6,kid_y7,kid_y8,kid_y9,kid_y10)
replace apar=apar-born_y
replace apar = 0 if apar == .

* Century year of parenthood
gen ypar=min(yc1,yc2,yc3,yc4,yc5,yc6,yc7,yc8,yc9,yc10)

* selections
drop if ydis<yuni // drop if union starts before end
drop if (tdis==1|tdis==2) & ydis==. // drop if missing divorce
drop if ydis>yint & ydis~=. // impossible divorce year

* id info
gen id_union=(10*id_person)+x
distinct id_union
distinct id_person

egen nunions=sum(1), by(ccc)
gen order=x
label variable order "Order of union"
recode curuni (1/max=1)(else=0), gen(union0)
label variable union0 "Union is current"
label variable nunions "nr of unions"
label variable arid "resp nr" // unique within ccc
egen check=sum(1), by(arid ccc)
tab  check ccc, col

* Keep only the relevant variables
keep country ccc edu eduyrs eduisled dedu wom yint arid id_union id_person cbir  order union0 yuni ymar ydis tdis ypar yc1-yc10 auni apar nunions

save "$posted/ggs_allunions.dta", replace


********************************************************************************
* make person period file from union-person file
********************************************************************************

use "$posted/ggs_allunions.dta", clear

* recodes
recode yc* yuni ymar ydis (.a .b .c=.)

* all cohab unions that ended same calendar year or one calendar year later after the starting year
* regardless of whether there were children
gen trial=0
replace trial=1 if (yuni==ydis-1 & yuni~=. & ydis~=. & ymar==.) | ///
                   (yuni==ydis   & yuni~=. & ydis~=. & ymar==.)
label variable trial "Trial cohab union"
* some countries more trial unions, belgium is a bit off, sweden also high but expected
tab trial ccc, col

* which union is first child born
gen test=0
replace test=order if yc1>=(yuni-1) & (yc1 <= ydis | ydis==.)
egen unionkid=max(test), by(id_person ccc)
label variable unionkid "Union nr in which 1st kid is born" // assigned to all cases

* create personperiod file
gen yend=ydis // end is year of divorce or widowhood
replace yend=yint if union0==1 // end is interview year if union intact
gen window=yend-yuni+1
label variable window "Observed time interval per union"
drop if window==0 // one case
expand window

* time variables
sort ccc id_union
bysort ccc id_union: gen time = _n
label variable time "Years since start of union"
gen cytime=yuni+time-1 // minus one because first year is time=1
label variable cytime "Current time in years"
keep if time<=25

* event
gen div=0
replace div=1 if ydis==cytime & tdis==1 // event occurs at end of duration
replace div=. if ydis==cytime & tdis==2 // truncated at end of duration (widowhood)
label variable div "Separation"

* checks
list ccc id_union cc cytime yuni time ydis div in 1/300

* dynamic kid variable: time of birth and all later years
* assuming birth is after beginning and before end of union
* if kid is born one year before union start, include the kid in the union
foreach X of numlist 1/10{
replace yc`X'=yc`X'+1 if yc`X'==(yuni-1) & yc`X'~=. // add 1 year to the birth year
}
gen kid=0
foreach X of numlist 1/10{
replace kid=1 if cytime>=yc`X' & yc`X'>=yuni & yc`X'<=yend
}
label variable kid "Children"
gen nkids=0
foreach X of numlist 1/10{
replace nkids=nkids+1 if cytime>=yc`X' & yc`X'>=yuni & yc`X'<=yend
}
label variable nkids "Number of children"
recode nkids (1=1)(else=0), gen(k1)
recode nkids (2=1)(else=0), gen(k2)
recode nkids (3=1)(else=0), gen(k3)
recode nkids (4/max=1)(else=0), gen(k4)
label variable k1 "One child"
label variable k2 "Two children"
label variable k3 "Three children"
label variable k4 "Four+ children"

* age for kids born in the relationship
foreach X of numlist 1/10{
gen agekid_`X'=cytime-yc`X' if cytime>=yc`X' & yc`X'>=yuni & yc`X'<=yend
}

* prior unions
recode order (2/9=1)(else=0), gen(second)
label variable second "Higher order union"

* dynamic cohabitation variable
gen cohab=1
replace cohab=0 if cytime>=ymar
label variable cohab "Unmarried couple"
tab cohab ccc, col

save "$posted/ppfile_allunions", replace


********************************************************************************
* make kid file for ggs
********************************************************************************

use "$posted/ggs_excerpt.dta", clear


* setup kids long file
foreach X of numlist 1 2 3 4 5 6 7 8 9{
recode union_y`X' marr_y`X' sep_`X' (.a=.)(.b=.)(.c=.)
recode sep_`X' (2001 2901=1)(.=0) // 0 = widowed 1 = div or sep
gen yuni`X'=union_y`X'
gen ymar`X'=marr_y`X'
replace yuni`X'=min(yuni`X',ymar`X') // if union after marriage start is marriage
gen ydia`X'=sep_y`X'
gen ydib`X'=div_y`X'
gen ydis`X'=min(ydia`X',ydib`X')
gen tdis`X'=sep_`X'
label define tdis`X' 0 "intact" 1 "separated" 2 "widowed"
label values tdis`X' tdis
gen auni`X' = yuni`X' - born_y
}

// Year of interview
gen yint = year_s

// Birth cohort
gen cbir=born_y

// Children
forvalues x = 1/16{
gen yc`x' = kid_y`x'
gen ac`x' = kid_y`x' - born_y
gen dead`x' = kid_d`x'
}

reshape long yc dead, i(arid country) j(x)
recode yc (.a .b .c=.)
drop if yc==.
drop if dead==1

* id var
gen id_kid=(100*id_person)+x
distinct id_kid

* check file
gen order=x
tab order ccc,m

* keep relevant vars
keep country  ccc wom  edu eduyrs eduisled dedu yint arid id_kid id_person cbir order ydis* yuni* ymar* tdis* yc

save "$posted/ggs_allkids", replace


***************************************************************************************
* make person-year files for kids
***************************************************************************************

clear all
use "$posted/ggs_allkids.dta", clear

* in which union is child born
* allows for shotgun unions
gen union=.
replace union=1 if yc>=(yuni1-1) & (yc<=ydis1 | ydis1==.)
replace union=2 if yc>=(yuni2-1) & (yc<=ydis2 | ydis2==.)
replace union=3 if yc>=(yuni3-1) & (yc<=ydis3 | ydis3==.)
replace union=4 if yc>=(yuni4-1) & (yc<=ydis4 | ydis4==.)
replace union=5 if yc>=(yuni5-1) & (yc<=ydis5 | ydis5==.)
replace union=6 if yc>=(yuni6-1) & (yc<=ydis6 | ydis6==.)
replace union=7 if yc>=(yuni7-1) & (yc<=ydis7 | ydis7==.)
gen id_union=(10*id_person)+union
distinct id_union

* in which type of union is child born
gen bcohab=0
replace bcohab=1 if yc>=(yuni1-1) & (yc<=ydis1 | ydis1==.) & (yc<ymar1 | ymar1==.)
replace bcohab=1 if yc>=(yuni2-1) & (yc<=ydis2 | ydis2==.) & (yc<ymar2 | ymar2==.)
replace bcohab=1 if yc>=(yuni3-1) & (yc<=ydis3 | ydis3==.) & (yc<ymar3 | ymar3==.)
replace bcohab=1 if yc>=(yuni4-1) & (yc<=ydis4 | ydis4==.) & (yc<ymar4 | ymar4==.)
replace bcohab=1 if yc>=(yuni5-1) & (yc<=ydis5 | ydis5==.) & (yc<ymar5 | ymar5==.)
replace bcohab=1 if yc>=(yuni6-1) & (yc<=ydis6 | ydis6==.) & (yc<ymar6 | ymar6==.)
replace bcohab=1 if yc>=(yuni7-1) & (yc<=ydis7 | ydis7==.) & (yc<ymar7 | ymar7==.)

* pick the correct union for each kid
gen yuni=.
gen ymar=.
gen ydis=.
gen tdis=.
foreach X of numlist 1/7{
replace yuni=yuni`X' if union==`X'
replace ymar=ymar`X' if union==`X'
replace ydis=ydis`X' if union==`X'
replace tdis=tdis`X' if union==`X'
}
gen auni=yuni-cbir

* kids before and outside unions
drop if yuni==. // drop born outside a union

* all cohab unions that ended same calendar year or one calendar year later after the starting year
* regardless of whether there were children
gen trial=0
replace trial=1 if (yuni==ydis-1 & yuni~=. & ydis~=. & ymar==.) | ///
                   (yuni==ydis   & yuni~=. & ydis~=. & ymar==.)
drop if trial==1
label variable trial "Trial cohab union"

* create personperiod file
* window goes from birth to age 25 or interview 
gen yend=yc+24
replace yend=yint if yint < yc+24
* truncate window at dissolution if at/before age 18
replace yend=ydis if ydis~=. & ydis <= yc+24
* make window
gen window=yend-yc+1 
tab window
label variable window "Observed time interval per kid"
expand window

* time variables
* time variables
sort ccc id_kid
bysort ccc id_kid: gen agekid = _n
gen time=yc-yuni+agekid
gen cytime=yuni+time-1 
label variable cytime "Current time in years"

* divorce for kid
gen div=0
replace div=1 if cytime==ydis & tdis==1 // div
replace div=. if cytime==ydis & tdis==2 // widowhood
label variable div "Separation"

list yuni yc yend agekid time cytime ydis div if ydis~=. in 1/1000
tab agekid
* dynamic cohabitation variable
gen cohab=1
replace cohab=0 if cytime>=ymar
label variable cohab "Unmarried couple"
tab cohab
tab agekid

* checks
list ccc arid id_person id_kid id_union yc cytime agekid yuni ymar ydis yint div tdis  cohab in 1/300
sum ccc arid id_person id_kid id_union yc cytime agekid yuni ymar ydis yint div tdis  cohab

save "$posted/ppfile_allkids.dta", replace


