*--------------------------------- specify your path here! ---------------------------*

global dir 	"C:\Users\Thomas Leopold\Dropbox\Adult_Child"

*-------------------------------------------------------------------------------------*

global data			"$dir/0_data"		// HH, GGS, and UK files
global dofiles 		"$dir/1_dofiles"	// dofiles
global posted		"$dir/2_posted"		// prepared data ready for analysis
global tables		"$dir/3_tables" 	// tables
global graphs 		"$dir/4_graphs" 	// graphs
global temp 		"$dir/5_temp" 		// temporary files



********************************************************************************
* analyses of adults
********************************************************************************

use "$dir/2_posted/ppfile_allunions", clear

* layout issue
label variable div " "

* country values for graphs
gen cccnew="Belgium" if ccc==1
replace cccnew="Czech" if ccc==2
replace cccnew="Estonia" if ccc==3
replace cccnew="France" if ccc==4
replace cccnew="Hungary" if ccc==5
replace cccnew="Norway" if ccc==6
replace cccnew="Sweden" if ccc==7
replace cccnew="UK" if ccc==8

* selections
keep if yuni >= 1945 // post WWII unions
drop if yuni > 2005 
drop if auni > 50
drop if auni < 12
drop if yuni==yint // if married in interview year
drop if trial==1 // all cohab unions with start year <= end year + 1
drop if div==.

* time issues
gen timex=time/10
gen timex2=(time/10)*(time/10)
label variable timex "Union duration"
label variable timex2 "Union duration squared"
gen age=cytime-cbir
label variable age "Age"

* select window
keep if time<=23 

* N for in text
tab div cohab, row
tab div ccc
distinct id_union
distinct id_person


* Table 2 descriptives of xvars
gen cohab100=cohab*100
gen div100=div*100
gen kid100=kid*100
bys ccc: asdoc sum age edu time yuni ymar ydis auni cohab100 div100 kid100, ///
format stat(mean) replace  dec(1) label fs(10) title(Table 2. Means by country in person-period file in all years) save($tables/table2) 
bys ccc: asdoc sum age edu time yuni ymar ydis auni cohab100  kid100 if time==1, ///
 stat(mean) append  dec(1) label fs(10) title(First year) ///
 save($tables/table2) 
bys ccc: asdoc sum age edu time yuni ymar ydis auni cohab100 kid100 if cytime==ydis, ///
 stat(mean) append  dec(1) label fs(10) title(Separation year) ///
 save($tables/table2) 
bys ccc: asdoc sum age , ///
 stat(N) append  dec(0) label fs(10) title(All years) ///
 save($tables/table2) 
bys ccc: asdoc sum age  if time==1, ///
 stat(N) append  dec(0) label fs(10) title(First year) ///
 save($tables/table2) 
bys ccc: asdoc sum age  if cytime==ydis, ///
 stat(N) append  dec(0) label fs(10) title(Separation year)  ///
 save($tables/table2) 

* cohort issues
gen cuni=yuni/10 // scaled in decades
label variable cuni "Union cohort"
recode yuni ///
 (1945/1949=1)(1950/1954=2)(1955/1959=3)(1960/1964=4)(1965/1969=5) ///
 (1970/1974=6)(1975/1979=7)(1980/1984=8)(1985/1989=9)(1990/1994=10) ///
 (1995/1999=11)(2000/2005=12), gen(cunix)
label define cunix 1 " " 2 "50" 3 " " 4 "60" 5 " " 6 "70" 7 " " 8 "80" 9 " " 10 "90" 11 " " 12 "00"
label values cunix cunix
* 2005 included in 2000
* for one figure more detailed labels are possible
gen cunix2=cunix
label define cunix2 1 "45" 2 "50" 3 "55" 4 "60" 5 "65" 6 "70" 7 "75" 8 "80" 9 "85" 10 "90" 11 "95" 12 "00"
label values cunix2 cunix2 

* making vars for figures
gen edux=edu
gen kidx=kid
replace edux=edux*10
label define edux 91 "Low education (9.1)" 171 "High education (17.1)"
label values edux edux
label define kidx 0 "Childless couples" 1 "Parent couples"
label values kidx kidx

* save file for merging with kids later
gen kidad=0
label define kidad 0 "Adults" 1 "Children"
label values kidad kidad
save "$posted/adults", replace

* centering everything within ccc except time 
foreach X of varlist cuni kid edu auni wom cohab second{
egen m_`X'=mean(`X'), by(ccc)
replace `X'=`X'-m_`X'
}
gen cuni_2=cuni*cuni // needs to be done after centering
label variable cuni_2 "Union cohort squared"
gen edukid=kid*edu
label variable edukid "Education x Children"

* cohab interactions
gen cohab_kid=cohab*kid
gen cohab_edu=cohab*edu
label variable cohab "Cohabitation"
label variable cohab_kid "   x Children"
label variable cohab_edu "   x Education"

* cohort interactions
foreach X of varlist kid edu edukid wom cohab{
gen c_`X'=cuni*`X'
label variable c_`X' "   x Union cohort"
}

* figure 1 basic graphs
foreach x in Belgium  Czech Estonia France Hungary Norway Sweden UK {
logit div c.timex c.timex#c.timex i.cunix2 if cccnew=="`x'" , cluster(id_union)
margins, at(timex=(1)) noestimcheck post over(cunix2)  
est store marginsfig1`X' 
marginsplot, xdimension(cunix2) plot1opts(msymbol(D)) name(`x'1,replace) ///
 title("`x'")  xscale(range(1(1)12)) ylab(0(.01).08) plotregion(color(white)) legend(size(small)) ///
 xtitle(Union cohort) ytitle(Annual probability,size(small))  
}
graph combine Belgium1 Czech1 Estonia1 France1 Hungary1 Norway1 Sweden1 UK1 , ///
 fysize(70) fxsize(120) ///
 rows(2) title(Figure 1. Cohort trends in adult separation risks,size(small)) iscale(*.5) name(figure3,replace)
graph export "$graphs/figure1.pdf", replace


* table 3a
* baseline models
foreach X in Belgium Czech Estonia France Hungary Norway Sweden UK  {
eststo `X': logit div timex timex2 wom cuni cuni_2 edu       kid       edukid if cccnew=="`X'", cluster(id_person)
}
esttab Belgium Czech Estonia France Hungary Norway Sweden UK using "$tables/table3", ///
 b(3) ar2 nogap parentheses rtf replace ///
 label p noomitted nolz ///
 title("Table 3.- Event-history models of adults experiencing separation: Baseline models") ///
 stats(chi2  N N_clust  ,labels("Chi-2" "N union-years" "N clusters") fmt(%5.1f %9.0f %7.0f))  ///
 star(~ 0.10 * 0.05 ** 0.01) substitute("\fonttbl{\f0\fnil Times New Roman" "\fonttbl{\f0\fnil Calibri") ///
 keep(timex timex2  cuni cuni_2 edu kid edukid) nodep ///
 order(timex timex2  cuni cuni_2 edu kid edukid) nonumbers ///
 note(Note: Variables centered. Cohort divided by 10. P-values corrected for clustering of years in unions.) 

* table 3b
* event history models trends in the effects
foreach X in Belgium Czech Estonia France Hungary Norway Sweden UK  {
eststo `X': logit div timex timex2 wom  cuni cuni_2 edu c_edu kid c_kid  if cccnew=="`X'", cluster(id_person)
}
esttab Belgium Czech Estonia France Hungary Norway Sweden UK using "$tables/table3b", ///
 b(3) ar2 nogap parentheses rtf append ///
 label p noomitted nolz ///
 title("Table 3.- Event-history models of adults experiencing separation: Cohort interactions") ///
 stats(chi2  ,labels("Chi-2") fmt(%5.1f))  ///
 star(~ 0.10 * 0.05 ** 0.01) substitute("\fonttbl{\f0\fnil Times New Roman" "\fonttbl{\f0\fnil Calibri") ///
 keep(timex timex2 cuni cuni_2 edu c_edu kid c_kid ) nodep ///
 order(timex timex2 cuni cuni_2 edu c_edu kid c_kid ) nonumbers nonote
foreach X in Belgium Czech Estonia France Hungary Norway Sweden UK  {
eststo `X': logit div timex timex2 wom cuni cuni_2 edu c_edu kid c_kid edukid c_edukid if cccnew=="`X'", cluster(id_person)
}
esttab Belgium Czech Estonia France Hungary Norway Sweden UK using "$tables/table3b", ///
 b(3) ar2 nogap parentheses rtf append ///
 label p noomitted nolz ///
 stats(chi2  N N_clust  ,labels("Chi-2" "N union-years" "N clusters") fmt(%5.1f %9.0f %7.0f))  ///
 star(~ 0.10 * 0.05 ** 0.01) substitute("\fonttbl{\f0\fnil Times New Roman" "\fonttbl{\f0\fnil Calibri") ///
 keep(timex timex2 cuni cuni_2 edu c_edu kid c_kid edukid c_edukid) nodep ///
 order(timex timex2 cuni cuni_2 edu c_edu kid c_kid edukid c_edukid) nonumbers ///
 note(Note: Variables centered. Cohort divided by 10. P-values corrected for clustering of unions in persons (clusters are persons).) 

* table 4
* event history models controls for cohab added
foreach X in Belgium Czech Estonia France Hungary Norway Sweden UK  {
eststo `X': logit div timex timex2 wom cohab c_cohab cohab_kid cohab_edu cuni cuni_2 edu c_edu kid c_kid edukid c_edukid if cccnew=="`X'", cluster(id_person)
}
esttab Belgium Czech Estonia France Hungary Norway Sweden UK using "$tables/table4", ///
 b(3) ar2 nogap parentheses rtf append ///
 label p noomitted nolz ///
 title("Table 4.- Event-history models of adults experiencing separation: Including cohabitation effects") ///
 stats(chi2  N N_clust  ,labels("Chi-2" "N unions-years" "N clusters") fmt(%5.1f %9.0f %7.0f))  ///
 star(~ 0.10 * 0.05 ** 0.01) substitute("\fonttbl{\f0\fnil Times New Roman" "\fonttbl{\f0\fnil Calibri") ///
 keep (timex timex2 cuni cuni_2 cohab  c_cohab cohab_kid cohab_edu edu c_edu kid c_kid edukid c_edukid) nodep ///
 order(timex timex2 cuni cuni_2 cohab  c_cohab cohab_kid cohab_edu edu c_edu kid c_kid edukid c_edukid) nonumbers ///
 note(Note: Variables centered. Cohort divided by 10. P-values corrected for clustering of unions in persons (clusters are persons).) 

* figure 2 adults cohort x edu x kid
foreach X in Belgium Czech Estonia France Hungary Norway Sweden UK{
logit div c.timex c.timex#c.timex c.cunix c.cunix#c.cunix c.edux i.kidx i.kidx#c.cunix i.kidx#c.cunix#c.cunix  ///
 c.cunix#c.edux c.cunix#c.cunix#c.edux i.kidx#c.edux i.kidx#c.edux#c.cunix if cccnew=="`X'", cluster(id_person)
margins, at(edux=(91 171) timex=(1) ) noestimcheck post over(cunix kidx) 
est store marginsfig2`X' 
marginsplot, xdimension(cunix) plotdimension(kidx) plot2opts(msymbol(Th)) by(edux) ///
 name(`X'2,replace) title() ylab(0(.02).14) xlab(1(1)12) plotregion(color(white)) legend(size(small)) ///
 xtitle(Union cohort) ytitle(Annual separation probability,size(small)) byopt(title(`X')) 
}

graph combine Belgium2 Czech2 Estonia2 France2, ///
 fysize(90) fxsize(100) ///
 rows(2) title(Figure 2. Cohort trends in adult separation risks,size(small)) note([figure continues],size(tiny)) subtitle(" ") imargin(medium) ///
 iscale(*.6) name(figure2a,replace)
graph export "$graphs/figure2a.pdf", replace as(pdf) 

graph combine Hungary2 Norway2 Sweden2 UK2, ///
 fysize(90) fxsize(100) ///
 rows(2) title(Figure 2. Continued,size(small)) subtitle(" ") imargin(medium) ///
 iscale(*.6) name(figure2b,replace)
graph export "$graphs/figure2b.pdf", replace as(pdf) 


********************************************************************************
* analyses of kids and adults
********************************************************************************

use "$posted/ppfile_allkids", clear

gen kidad=1

* layout
label variable div " "

* country values for graphs
gen cccnew="Belgium" if ccc==1
replace cccnew="Czech" if ccc==2
replace cccnew="Estonia" if ccc==3
replace cccnew="France" if ccc==4
replace cccnew="Hungary" if ccc==5
replace cccnew="Norway" if ccc==6
replace cccnew="Sweden" if ccc==7
replace cccnew="UK" if ccc==8

* selections for kid file
keep if yuni >= 1945 // post WWII unions
drop if yuni>2005 // too recent to separate
drop if auni > 50
drop if auni < 12
drop if yuni==yint // if married in interview year
drop if div==.
drop if edu==.

* time dependence
gen timex=time/10
gen timex2=timex*timex
label variable timex "Union duration"
label variable timex2 "Union duration squared"

* cohort issues
gen cuni=yuni/10 // scaled in decades
label variable cuni "Union cohort"
recode yuni ///
 (1945/1949=1)(1950/1954=2)(1955/1959=3)(1960/1964=4)(1965/1969=5) ///
 (1970/1974=6)(1975/1979=7)(1980/1984=8)(1985/1989=9)(1990/1994=10) ///
 (1995/1999=11)(2000/2005=12), gen(cunix)
label define cunix 1 " " 2 "50" 3 " " 4 "60" 5 " " 6 "70" 7 " " 8 "80" 9 " " 10 "90" 11 " " 12 "00"
label values cunix cunix 
table cunix
* 2005 included in 2000

* select window
keep if agekid<=18

* N for in text
distinct id_kid 

* making vars for figures
gen edux=edu
gen kidx=kid
replace edux=edux*10
label define edux 91 "Low education (9.1)" 171 "High education (17.1)"
label values edux edux
label define kidx 0 "Childless couples" 1 "Parent couples"
label values kidx kidx

* add adults
append using "$posted/adults"

* centering
foreach X of varlist cuni edu cohab{
egen m_`X'=mean(`X'), by(ccc)
replace `X'=`X'-m_`X'
}
gen cuni_2=cuni*cuni
label variable cuni_2 "Union cohort squared"

* cohort interactions
gen c_edu=cuni*edu
label variable c_edu "   x Union cohort"

* ad interactions
label variable kidad "Child perspective"
gen edu_kidad=kidad*edu
gen c_kidad=kidad*cuni
gen c_edu_kidad=kidad*cuni*edu
label variable edu_kidad "Child perspective x Education"
label variable c_kidad "Child perspective x Union cohort"
label variable c_edu_kidad "    x Union cohort"

* table 5
* event history models kids and adults
ssc install vcemway, replace
foreach X in Belgium Czech Estonia France Hungary Norway Sweden UK  {
eststo `X': vcemway logit div timex timex2 cuni cuni_2 edu c_edu kidad c_kidad edu_kidad if cccnew=="`X'" , cluster(id_union id_person)
}
esttab Belgium Czech Estonia France Hungary Norway Sweden UK using "$tables/table5", ///
 b(3) ar2 nogap parentheses rtf append ///
 label p noomitted nolz ///
 title("Table 5.- Event-history models of children and adults experiencing (parental) separation") ///
 stats(chi2  ,labels("Chi-2" ) fmt(%5.1f ))  ///
 star(~ 0.10 * 0.05 ** 0.01) substitute("\fonttbl{\f0\fnil Times New Roman" "\fonttbl{\f0\fnil Calibri") ///
 keep(timex timex2  cuni cuni_2 edu c_edu *ad*) nodep ///
 order(timex timex2  cuni cuni_2 edu c_edu *ad*) nonumbers nonote
foreach X in Belgium Czech Estonia France Hungary Norway Sweden UK  {
eststo `X': vcemway logit div timex timex2 cuni cuni_2 edu c_edu kidad c_kidad edu_kidad c_edu_kidad if cccnew=="`X'", cluster(id_union id_person)
}
esttab Belgium Czech Estonia France Hungary Norway Sweden UK using "$tables/table5", ///
 b(3) ar2 nogap parentheses rtf append ///
 label p noomitted nolz ///
 stats(chi2  N N_clust1 N_clust2  ,labels("Chi-2" "N" "N clusters 1" "N clusters 2") fmt(%5.1f %9.0f %7.0f %7.0f))  ///
 star(~ 0.10 * 0.05 ** 0.01) substitute("\fonttbl{\f0\fnil Times New Roman" "\fonttbl{\f0\fnil Calibri") ///
 keep(timex timex2 cuni cuni_2 edu c_edu *ad*) nodep ///
 order(timex timex2  cuni cuni_2 edu c_edu *ad*) nonumbers ///
 note(Note: Variables centered. Cohort divided by 10. P-values corrected for multiway clustering of unions and adults/parents. Clusters 1 are unions, clusters 2 are adults/parents.) 
 

* figure 3
* kids and adults
foreach X in Belgium  Czech Estonia France Hungary Norway Sweden UK {
eststo `X': logit div c.timex c.timex#c.timex c.cunix c.cunix#c.cunix c.edux i.kidad c.edux#i.kidad ///
  c.cunix#c.edux c.cunix#i.kidad c.cunix#c.edux#i.kidad if cccnew=="`X'", cluster(id_person)
margins, at(edux=(91 171) timex=(1) )  noestimcheck post over(cunix kidad) 
est store marginsfig3`X' 
marginsplot, xdimension(cunix) plotdimension(kidad) plot2opts(msymbol(Th))  name(`X'3,replace) ylab(0(.02).10)  xscale(range(1(1)12)) plotregion(color(white)) legend(size(small)) ///
 xtitle(Union cohort) ytitle((Parental) separation risk,size(small))   byopt(title("`X'"))
}
label define kidad 0 "Adults" 1 "Children", replace
label values kidad kidad
foreach X in Belgium  Czech Estonia France Hungary Norway Sweden UK {
est restore marginsfig3`X' 
margins
marginsplot, xdimension(cunix) plotdimension(kidad) plot2opts(msymbol(Th))  name(`X'3,replace) ylab(0(.02).07)  xscale(range(1(1)12)) plotregion(color(white)) legend(size(small)) ///
 xtitle(Union cohort) ytitle((Parental) separation risk,size(small))   byopt(title("`X'"))
}
graph combine Belgium3 Czech3 Estonia3 France3, ///
 fysize(90) fxsize(100) ///
 rows(2) title(Figure 3. Cohort trends in separation risks of adults and children by education,size(small)) note([figure continues],size(tiny)) subtitle(" ") ///
 imargin(medium) iscale(*.6) name(figure3a,replace)
graph export "$graphs/figure3a.pdf", replace as(pdf) 

graph combine Hungary3 Norway3 Sweden3 UK3, ///
 fysize(90) fxsize(100) ///
 rows(2) title(Figure 3. Continued,size(small)) subtitle(" ") imargin(medium) ///
 iscale(*.6) name(figure3b,replace)
graph export "$graphs/figure3b.pdf", replace as(pdf) 

save "$posted/pooled-adults-kids", replace

********************************************************************************
* check at what union durations kids enter a union
********************************************************************************
use "$posted/pooled-adults-kids", clear
replace timex=timex*10
tab timex if kidad==0
tab agekid if kidad==1
bys cccnew: tab timex if agekid==1 & kidad==1
tab timex if agekid==1 & kidad==1
sum timex if agekid==18
* median is 5 years so we go from 5 to 22 for kids
* and we go from 1 to 18 for adults

********************************************************************************
* make adults life table for each combination 
********************************************************************************
clear all
use "$posted/pooled-adults-kids", clear
foreach L of numlist 1/8 {
foreach K of numlist 0 {
foreach E of numlist 91 171 {
foreach C of numlist 1/12 {
use "$posted/pooled-adults-kids", clear
keep if ccc==`L'
*replace edux=edux*10
replace timex=timex*10
* make basen [only for adults]
gen temp1=1 if timex==1
tab temp1
egen nrisk=sum(temp1) if kidad==`K' & edux==`E' & cunix==`C'
sum nrisk
* calculate risks
logit div c.timex c.timex#c.timex c.cunix c.cunix#c.cunix c.edux i.kidad c.edux#i.kidad c.cunix#c.edux c.cunix#i.kidad c.cunix#c.edux#i.kidad 
 margins, at( kidad=(`K') edux=(`E') cunix=(`C') timex=(1(1)18) ) noestimcheck post nose noci
 matrix riske = r(table)
 svmat riske
* make data in life table form
egen basen=max(nrisk)
keep riske* basen 
keep if riske1~=.
sum
gen key=_n
reshape long riske, i(key) j(timex)
* add variables for this life table
gen kidad=`K'
gen edux=`E'
gen cunix=`C'
gen ccc=`L'
sum
* calculate survival and standard errors for union duration 1-18
gen nsur=basen if timex==1
sort timex
foreach X of numlist 2/18{
replace nsur=nsur[_n-1]-(nsur[_n-1]*riske[_n-1]) if timex==`X'
}
sum
gen ndiv=riske*nsur
gen psur=nsur/basen
gen dnd=ndiv/(nsur*(nsur-ndiv))
egen sdnd=sum(dnd)
gen error=psur*sqrt(sdnd)
gen lower=psur-1.96*error
gen upper=psur+1.96*error
gen pdiv=1-psur
gen slower=1-upper
gen supper=1-lower
* truncate upper and lower bounds
recode slower supper (min/0=0)(1/max=1)
* labels
label variable basen "Base N"
label variable psur "Proportion intact"
label variable pdiv "Proportion separated"
label variable cunix "Cohort"
label variable edux "Education"
label variable kidad "Perspective"
label variable ccc "Country"
label variable error "Standard error"
label variable lower "Lower bound survival proportion"
label variable upper "Upper bound survival proportion"
label variable slower "Lower bound separation proportion"
label variable supper "Upper bound separation proportion"
keep timex basen psur lower upper pdiv slower supper error kidad edux cunix ccc
keep if timex==18
sum
save "$temp/survival_k`K'_e`E'_c`C'_l`L'", replace
}
}
}
}

********************************************************************************
* make kids life table for each combination 
********************************************************************************
clear all
use "$posted/pooled-adults-kids", clear
foreach L of numlist 1/8 {
foreach K of numlist 1 {
foreach E of numlist 91 171 {
foreach C of numlist 1/12 {
use "$posted/pooled-adults-kids", clear
keep if ccc==`L'
*replace edux=edux*10
replace timex=timex*10
* calculate risks
logit div c.timex c.timex#c.timex c.cunix c.cunix#c.cunix c.edux i.kidad c.edux#i.kidad c.cunix#c.edux c.cunix#i.kidad c.cunix#c.edux#i.kidad 
 margins, at( kidad=(`K') edux=(`E') cunix=(`C') timex=(5(1)22) ) noestimcheck post nose noci
 matrix riske = r(table)
 svmat riske
* make data in life table form
keep riske* 
keep if riske1~=.
gen key=_n
reshape long riske, i(key) j(timex)
* add variables for this life table
gen kidad=`K'
gen edux=`E'
gen cunix=`C'
gen ccc=`L'
* calculate survival for union durarion 5-22
* note that timex is now based on the margins, which are listed from 1-18
gen nsur=1 if timex==1
sort timex
foreach X of numlist 2/18{
replace nsur=nsur[_n-1]-(nsur[_n-1]*riske[_n-1]) if timex==`X'
}
gen psur=nsur
gen pdiv=1-psur
sum
* labels
label variable psur "Proportion intact"
label variable pdiv "Proportion separated"
label variable cunix "Cohort"
label variable edux "Education"
label variable kidad "Perspective"
label variable ccc "Country"
keep timex psur pdiv kidad edux cunix ccc
keep if timex==18
sum
save "$temp/survival_k`K'_e`E'_c`C'_l`L'", replace
}
}
}
}

* merge all life tables 
clear all
foreach L of numlist 1/8{
foreach K of numlist 0 1{
foreach E of numlist 91 171{
foreach C of numlist 1/12 {
append using "$temp/survival_k`K'_e`E'_c`C'_l`L'"
}
}
}
}
save "$posted/survival", replace
********************************************************************************
* make figure
********************************************************************************
use "$posted/survival", clear
gen sep=pdiv
tab cunix, sum(basen)
label define edux 91 "Lower educated" 171 "Higher educated"
label values edux edux
label define kidad 0 "Adults" 1 "Children"
label values kidad kidad
label variable kidad "Perspective"
label define cunix 2 "1950" 10 "1990" 11 "1995"
label values cunix cunix
label variable pdiv "Cumulative separation"
* country values for graphs
gen cccnew="Belgium" if ccc==1
replace cccnew="Czech" if ccc==2
replace cccnew="Estonia" if ccc==3
replace cccnew="France" if ccc==4
replace cccnew="Hungary" if ccc==5
replace cccnew="Norway" if ccc==6
replace cccnew="Sweden" if ccc==7
replace cccnew="UK" if ccc==8
tab cccnew
replace pdiv=pdiv*100
keep if cunix==2|cunix==11
foreach X in Belgium Czech Estonia France Hungary Norway Sweden UK {
graph bar pdiv if cccnew=="`X'", over(cunix, gap(25) label(labsize(vsmall))) over(kidad) over(edux) ///
 blabel(bar, format(%4.1f)) ///
 legend(placement(s) si(small) region(lc(none) fc(none) ls(none)) keygap(*.5) colgap(*.5) ) ///
   ylabel(0(10)60,labsize(small)) ytitle("Cumulative separation",size(small)) title("`X'") graphregion(color(white)) note(" ") name("`X'",replace) 
}

graph combine Belgium Czech Estonia France Hungary Norway Sweden UK , ///
 fysize(90) fxsize(150) ///
 rows(2) title(Figure 4. Cumulative (parental) separation percentages,size(small)) ///
 note("Note: Percentages based on predicted annual risks of the model in Table 3.",size(tiny)) subtitle(" ") imargin(medium) ///
 iscale(*.55) name(figure4,replace) graphregion(color(white))
graph export "$graphs/figure4.pdf", replace as(pdf) 


